/*
 * Copyright (c) 2001 University of Bologna
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Library Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library Public License for more details.
 *
 * You should have received a copy of the GNU Library Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package anthill;

/**
 *  This interface contains the methods called by a anthill
 *  on an agent when it is received by other sites.
 *
 *  @author Alberto Montresor
 *  @version $REVISION$
 */
public interface Ant
{

  
  /**
   *  Return the genetic code of this ant. This method may be invoked by 
   *  an anthill on an ant to extract its genetic code and store it for 
   *  future use.  
   */
  public GeneticCode getGeneticCode();

  
  /**
   *  Set the query string to be performed. The interpretation of
   *  the query string depends on the particular implementation.
   *
   *  @param query the query to be performed
   */
  public void setQuery(String query);
  
  
  /**
   *  This method encapsulate the computation performed by the
   *  ant. It is invoked once by an anthill when the ant is
   *  received by another anthill, or when the ant is generated
   *  locally. The run method must be executed in a controlled
   *  environment, meaning that the ant cannot be enabled to
   *  access anthill resources besides of the methods provided
   *  by the AntView interface.
   *
   *  @param view reference to the AntView object which
   *    constitutes the controlled environment of the ant
   */
  public void run(AntView view);

  
} // END Ant


