/*
 * Copyright (c) 2001 University of Bologna
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Library Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library Public License for more details.
 *
 * You should have received a copy of the GNU Library Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package anthill;

/**
 *  Factory interface for creating ants. This interface is used by
 *  anthills to create ant which will be used to perform searches
 *  in the anthill network.
 *
 *  @author Alberto Montresor
 *  @version $REVISION$
 */
public interface AntFactory
{
  
  /**
   *  Factory method for creating ants. The genetic code of the
   *  ant must be specified, together with the initial time-to-live.
   *  The genetic code is interpreted by the particular ant species;
   *  if the genetic code is not compatible with the ant species, an
   *  <CODE>IllegalArgumentException</CODE> is thrown.
   * 
   *  @param code the genetic code to be used for the generated ant
   *  @param ttl the initial time-to-live value, which can be used
   *    by the ant implementation to set up resources.
   *  @throws IllegalArgumentException if the genetic code is not
   *   compatible (e.g., it longer or shorter) with the specified
   *   ant species.
   */
  public Ant getAnt(GeneticCode code, int ttl);

  
} // END AntFactory


