/*
 * Copyright (c) 2001 University of Bologna
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Library Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library Public License for more details.
 *
 * You should have received a copy of the GNU Library Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package anthill;

import java.io.*;

/**
 *  Listener interface which must be implemented by objects
 *  that need to be notified about the results of a query.
 *
 *  @author Alberto Montresor
 *  @version $REVISION$
 */
public interface QueryListener
{
  
  /**
   *  Upcall method used to notify this listener about
   *  the fact that the associated query has returned
   *  the specified set of resources.
   * 
   *  @param resources the resources found.
   */
  public void returnResources(Resource[] resources);
  
  
  /**
   *  Upcall method used to notify this listener about the
   *  fact that no more results will be delivered.
   */
  public void complete();
  
} // END QueryListener

