/*
 * Copyright (c) 2001 University of Bologna
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Library Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library Public License for more details.
 *
 * You should have received a copy of the GNU Library Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package anthill;

import anthill.util.*;

/**
 *  The <CODE>Storage</CODE> interface represents the storage section of an 
 *  Anthill application. Resources maintained by a <CODE>Storage</CODE> 
 *  object may be retrieved by invoking the <CODE>getResource()</CODE> 
 *  method. Resources may be added to a storage by invoking methods
 *  <CODE>addAntResource()</CODE> and <CODE>addClientResource()</CODE>.
 *  The former method is invoked by ants through their associated
 *  <CODE>AntView</CODE> object, while the latter is invoked by Anthill
 *  clients. 
 *  <p>
 *  Depending on the implementation, different storage policies
 *  may be adopted for resources inserted by ants and clients.
 *  For example, ants resources may be handled with a LRU policy,
 *  while client resource may be stored permanently.
 *
 *  @author Alberto Montresor
 *  @version $REVISION$
 */
public interface Storage
extends Clearable
{

  /**
   *  Returns the set of resources stored locally which satisfy
   *  the query. If no resource can be found, a <CODE>null</CODE> value is
   *  returned.
   *
   *  @param query The identifier of the resource
   */
  public Resource[] getResources(String query);

  /**
   *  Add a resource to the storage. This method is invoked 
   *  from an anthill on behalf of an ant. 
   *
   *  @param resource the resource to be added
   */
  public void addAntResource(Resource resource);
  
  /**
   *  Add a resource to the storage. This method is invoked 
   *  from an anthill on behalf of an anthill client. 
   *
   *  @param resource the resource to be added
   */
  public void addClientResource(Resource resource);
  
} // END Storage
