/*
 * Copyright (c) 2001 University of Bologna
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Library Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library Public License for more details.
 *
 * You should have received a copy of the GNU Library Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package anthill.genie;

import anthill.gf.*;
import anthill.util.Printable;


/**
 *  Class ExperimentFactoryImpl is a simple implementation of
 *  the ExperimentFactory interface.
 *
 *  @author Alberto Montresor
 *  @version $REVISION$
 */
public class ExperimentFactoryImpl
extends Printable
implements ExperimentFactory
{
  
  ////////////////////////////////////////////////////////////////////////////////////////////
  // Fields
  ////////////////////////////////////////////////////////////////////////////////////////////

  /** Scenario factory to be used to create new scenarios */
  private ScenarioFactory scenariof;
  
  /** Number of scenarios to be created */
  private int size;
  
  
  ////////////////////////////////////////////////////////////////////////////////////////////
  // Constructor
  ////////////////////////////////////////////////////////////////////////////////////////////

  /**
   *  Instantiates a new experiment factory
   *
   *  @throws IllegalArgumentException if the size argument is less or equal
   *    than zero.
   */
  public ExperimentFactoryImpl(ScenarioFactory scenariof, int size)
  {
    this.scenariof = scenariof;
    this.size = size;
    if (size <= 0)
      throw new IllegalArgumentException("Number of scenarios must be greater than zero");
  }

  
  ////////////////////////////////////////////////////////////////////////////////////////////
  // Methods from ExperimentFactory
  ////////////////////////////////////////////////////////////////////////////////////////////

  // Comment inherited by interface
  public Experiment getExperiment()
  {
    return new ExperimentImpl(this);
  }

  
  ////////////////////////////////////////////////////////////////////////////////////////////
  // "getter" methods for fields (package visibility)
  ////////////////////////////////////////////////////////////////////////////////////////////
  
  /**
   *  Return the scenario factory included in this object
   */
  final ScenarioFactory getScenarioFactory()
  {
    return scenariof;
  }

  /**
   *  Return the size parameter included in this object
   */
  final int getSize()
  {
    return size;
  }

} // END ExperimentFactoryImpl

