/*
 * Copyright (c) 2001 University of Bologna
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Library Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library Public License for more details.
 *
 * You should have received a copy of the GNU Library Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package anthill.gf;

import anthill.*;
import anthill.util.*;

/**
 *  An Experiment is constituted by a collection of Scenario's.
 *  The fitness of one or more genetic codes can evaluated on an 
 *  Experiment by evaluating the fitness on each of the Scenario's 
 *  constituting it.
 *
 *  @author Alberto Montresor
 *  @version $REVISION$
 */
public interface Experiment
extends Clearable
{
  
  /**
   *  Set the genetic code to be evaluated. Depending on the implementation 
   *  of this interface, this method may be invoked more than once, for
   *  example to evaluate the fitness of a collection of genetic codes.
   */
  public void addGeneticCode(GeneticCode code);

  /**
   *  Execute the experiment, i.e. evaluate the fitness of the genetic code(s).
   */
  public void evaluate();

  /**
   *  Return the evaluated fitness. This operation is separated from
   *  the actual evaluation in order to enable the computation of
   *  fitness values using "resource sharing" techniques.
   */
  public double getFitness();
  
} // END Experiment

