/*
 * Copyright (c) 2001 University of Bologna
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Library Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library Public License for more details.
 *
 * You should have received a copy of the GNU Library Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package anthill.gf;

import anthill.*;
import anthill.util.*;

/**
 *  Interface Scenario represents a particular test-case on
 *  which the fitness of one or more genetic codes can be 
 *  evaluated. A set of scenarios constitutes an Experiment.
 *  
 *  @author Alberto Montresor
 *  @version $REVISION$
 */
public interface Scenario
extends Clearable
{
  
  /**
   *  Set the genetic code(s) to be evaluated. Depending on the implementation 
   *  of this interface, this method may be invoked more than once, for
   *  example to evaluate the fitness of a set of genetic codes
   */
  public void addGeneticCode(GeneticCode code);

  
  /**
   *  Evaluate the fitness of the specified genetic code(s) for
   *  this scenario.
   */
  public double evaluate();

  
} // END Scenario

