/*
 * Copyright (c) 2001 University of Bologna
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Library Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library Public License for more details.
 *
 * You should have received a copy of the GNU Library Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package anthill.nestor;

import anthill.*;

/**
 *  Class LocalAid is the implementation of AnthillId for the
 *  off-line simulation. Unique identifier are generated using
 *  a counter of type long. Each identifier is uniquely 
 *  associated with the anthill gate, in order to avoid the
 *  problems of having
 *
 *  @author Alberto Montresor
 *  @version $REVISION$
 */
public class LocalAid
implements AnthillId
{
  
  ////////////////////////////////////////////////////////////////////////////////////////////
  // Static section
  ////////////////////////////////////////////////////////////////////////////////////////////

  /** Counter used to generate unique identifiers */
  private static long counter = 0;
  
  
  ////////////////////////////////////////////////////////////////////////////////////////////
  // Fields
  ////////////////////////////////////////////////////////////////////////////////////////////

  /** Identifier */
  private long id;
  
  /** Gate object associated with this id */
  private LocalGate gate;
  
  

  ////////////////////////////////////////////////////////////////////////////////////////////
  // Constructor
  ////////////////////////////////////////////////////////////////////////////////////////////
  
  /**
   *  Builds a new local identifier
   */
  public LocalAid(LocalGate gate)
  {
    id = ++counter;
    this.gate = gate;
  }
  
  
  ////////////////////////////////////////////////////////////////////////////////////////////
  // Methods
  ////////////////////////////////////////////////////////////////////////////////////////////
  
  public LocalGate getGate()
  {
    return gate;
  }
  
  
  ////////////////////////////////////////////////////////////////////////////////////////////
  // Methods from Object
  ////////////////////////////////////////////////////////////////////////////////////////////
  
  /**
   *  Check whether this <CODE>LocalAid</CODE> is equal to the specified object.
   */
  public boolean equals(Object obj)
  {
    if (obj != null && obj instanceof LocalAid) {
      LocalAid id = (LocalAid) obj;
      return (this.id == id.id);
    } else {
      return false;
    }
  }

  /**
   *  Returns a hash code value for the object.
   */
  public int hashCode()
  {
    return (int) id;
  }
  
  /**
   *  Returns a string representation of the object.
   */
  public String toString()
  {
    StringBuffer buf = new StringBuffer();
    buf.append("[");
    buf.append(this.getClass().getName());
    buf.append(": ");
    buf.append(id);
    buf.append("]");
    return buf.toString();
  }
  
} // END LocalAid

