/*
 * Copyright (c) 2001 University of Bologna
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Library Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library Public License for more details.
 *
 * You should have received a copy of the GNU Library Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package anthill.nestor;

import anthill.*;
import anthill.util.*;

/**
 *
 *  @author Alberto Montresor
 *  @version $REVISION$
 */
public class SimulationManager
implements Manager
{
  
  ////////////////////////////////////////////////////////////////////////////////////////////
  // Fields
  ////////////////////////////////////////////////////////////////////////////////////////////

  /** Queue containing the agents to be computed */
  Queue queue;

  
  ////////////////////////////////////////////////////////////////////////////////////////////
  // Constructor
  ////////////////////////////////////////////////////////////////////////////////////////////

  /**
   *  
   */
  public SimulationManager()
  {
    queue = new Queue();
  }

  ////////////////////////////////////////////////////////////////////////////////////////////
  // Methods from Manager
  ////////////////////////////////////////////////////////////////////////////////////////////

  /**
   *  Adds an agent to the queue of agent to be executed
   *
   *  @param view the agent to be added is encapsulated
   *    in a AntView
   */
  public void add(AntView view)
  {
    queue.add(view);
  }
  
  
  /**
   *  Execute an agent maintened in this Manager
   */
  public void execute()
  {
    AntView view = (AntView) queue.remove();
    if (view != null) {
      Ant ant = view.getAnt();
      ant.run(view);
    }
  }

  ////////////////////////////////////////////////////////////////////////////////////////////
  // Methods from Clearable
  ////////////////////////////////////////////////////////////////////////////////////////////
  
  /**
   *  Restore the object to its initial state.
   */
  public void clear()
  {
    // FIXME Add method clear to queue, in order to avoid re-initializing
    queue = new Queue();
  }
  
} // END Manager
