/*
 * Copyright (c) 2001 University of Bologna
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Library Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library Public License for more details.
 *
 * You should have received a copy of the GNU Library Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package anthill.yessensis;

/**
 *
 *  @author Alberto Montresor
 *  @version $REVISION$
 */
public class Pheromone
{

  ////////////////////////////////////////////////////////////////////////////////////////////
  // Fields
  ////////////////////////////////////////////////////////////////////////////////////////////

  /** Mapping between the space of hash keys and the pheromone values */
  private float[] map;

  /** Size of the map */
  private int size;
  
  
  ////////////////////////////////////////////////////////////////////////////////////////////
  // Constructor
  ////////////////////////////////////////////////////////////////////////////////////////////

  /**
   *  Construct a new <CODE>Pheromone</CODE> object with a resource map
   *  of the specified size.
   */
  public Pheromone(int size, float init)
  {
    this.size = size;
    map = new float[size];
    for (int i=0; i < size; i++) {
      map[i] = init;
    }
  }

  
  ////////////////////////////////////////////////////////////////////////////////////////////
  // Methods
  ////////////////////////////////////////////////////////////////////////////////////////////

  /**
   *  Return the pheromone value associated to the hash identifier
   */
  public float getValue(int hash)
  {
    return (map[((hash % size)+size)%size]);
  }
  
  /**
   *  Set the pheromone value associated to the hash identifier
   */
  public void setValue(int hash, float value)
  {
    map[((hash % size)+size)%size] = value;
  }

} // END Pheromone

