/*
 * Copyright (c) 2001 University of Bologna
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Library Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library Public License for more details.
 *
 * You should have received a copy of the GNU Library Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package anthill.yessensis;

import anthill.*;

/**
 *  Factory for Yessensis ants.
 * 
 *  @author Alberto Montresor
 *  @version $REVISION$
 */
public class YessensisFactory
implements AntFactory
{
  
  ////////////////////////////////////////////////////////////////////////////////////////////
  // Fields
  ////////////////////////////////////////////////////////////////////////////////////////////

  /** Pheromone factory needed to create pheromone trails */
  PheromoneFactory pheromonef;
  
  ////////////////////////////////////////////////////////////////////////////////////////////
  // Constructors
  ////////////////////////////////////////////////////////////////////////////////////////////

  /**
   * Short concise description.
   * @param pheromonef description.
   */
  public YessensisFactory(PheromoneFactory pheromonef)
  {
    this.pheromonef = pheromonef;
  }

  
  ////////////////////////////////////////////////////////////////////////////////////////////
  // Methods
  ////////////////////////////////////////////////////////////////////////////////////////////
  
  /**
   *  Factory method for creating Yessensis ants. The genetic code of 
   *  the ant must be specified, together with the initial time-to-live. 
   *  The genetic code is interpreted by Yessensis; in the case of 
   *  incompatibilities, an <CODE>IllegalArgumentException</CODE> is thrown.
   * 
   *  @param code the genetic code to be used for the generated ant
   *  @param ttl the initial time-to-live value, used by Yessensis to
        set up the size of the tabu list.
   *  @throws IllegalArgumentException if the genetic code is not
   *   compatible (e.g., it longer or shorter) with Yessensis.
   */
  public Ant getAnt(GeneticCode code, int ttl)
  {
    return new Yessensis(code, ttl, pheromonef);
  }
  
} // END YessensisFactory


